@@ -14,7 +14,7 @@ if something goes wrong here, it's almost definitely my fault
 rather than a problem with the libftdi library.
 """
 
-__VERSION__ = "0.10.3"
+__VERSION__ = "0.11"
 __AUTHOR__ = "Ben Bass"
 
 
@@ -41,3 +41,10 @@ BB_INPUT = bitbang.BB_INPUT
 FLUSH_BOTH = driver.FLUSH_BOTH
 FLUSH_INPUT = driver.FLUSH_INPUT
 FLUSH_OUTPUT = driver.FLUSH_OUTPUT
+
+# Use these for interface_select on multiple-interface devices
+INTERFACE_ANY = 0
+INTERFACE_A = 1
+INTERFACE_B = 2
+INTERFACE_C = 3
+INTERFACE_D = 4
