@@ -138,29 +138,40 @@ class Driver(object):
 
 class Device(object):
     """
-    Device([device_id[, mode [, encoding [, lazy_open]]]) -> Device instance
-
-    represents a single FTDI device accessible via the libftdi driver.
-    Supports a basic file-like interface (open/close/read/write, context
-    manager support).
-
-    device_id - an optional serial number of the device to open.
-      if omitted, this refers to the first device found, which is
-      convenient if only one device is attached, but otherwise
-      fairly useless.
-
-    mode - either 'b' (binary) or 't' (text). This primarily affects
-      Python 3 calls to read() and write(), which will accept/return
-      unicode strings which will be encoded/decoded according to the given...
-
-    encoding - the codec name to be used for text operations.
-
-    lazy_open - if True, then the device will not be opened immediately - the
-      user must perform an explicit open() call prior to other operations.
+    Represents a connection to a single FTDI device
     """
+
     def __init__(self, device_id=None, mode="b",
                  encoding="latin1", lazy_open=False,
-                 buffer_size=0, interface=None):
+                 chunk_size=0, interface_select=None):
+        """
+        Device([device_id[, mode, [OPTIONS ...]]) -> Device instance
+
+        represents a single FTDI device accessible via the libftdi driver.
+        Supports a basic file-like interface (open/close/read/write, context
+        manager support).
+
+        device_id - an optional serial number of the device to open.
+            if omitted, this refers to the first device found, which is
+            convenient if only one device is attached, but otherwise
+            fairly useless.
+
+        mode - either 'b' (binary) or 't' (text). This primarily affects
+            Python 3 calls to read() and write(), which will accept/return
+            unicode strings which will be encoded/decoded according to the given...
+
+        encoding - the codec name to be used for text operations.
+
+        lazy_open - if True, then the device will not be opened immediately -
+            the user must perform an explicit open() call prior to other
+            operations.
+
+        chunk_size - if non-zero, split read and write operations into chunks
+            of this size. With large or slow accesses, interruptions (i.e.
+            KeyboardInterrupt) may not happen in a timely fashion.
+
+        interface_select - select interface to use on multi-interface devices
+        """
         self._opened = False
         self.driver = Driver()
         self.fdll = self.driver.fdll
@@ -182,12 +193,12 @@ class Device(object):
         self._baudrate = 9600
         # defining softspace allows us to 'print' to this device
         self.softspace = 0
-        # buffer_size (if not 0) chunks the reads and writes
+        # chunk_size (if not 0) chunks the reads and writes
         # to allow interruption
-        self.buffer_size = buffer_size
+        self.chunk_size = chunk_size
         # interface can be set for devices which have multiple interface
         # ports (e.g. FT4232, FT2232)
-        self.interface = interface
+        self.interface_select = interface_select
         # lazy_open tells us not to open immediately.
         if not lazy_open:
             self.open()
@@ -212,8 +223,9 @@ class Device(object):
             del self.ctx
             raise FtdiError(msg)
 
-        if self.interface is not None:
-            self.fdll.ftdi_set_interface(byref(self.ctx), self.interface)
+        if self.interface_select is not None:
+            self.fdll.ftdi_set_interface(byref(self.ctx),
+                self.interface_select)
 
         # Try to open the device.  If this fails, reset things to how
         # they were, but we can't use self.close as that assumes things
@@ -289,18 +301,19 @@ class Device(object):
         read(length) -> bytes/string of up to `length` bytes.
 
         read upto `length` bytes from the FTDI device
-        return type depends on self.mode - if 'b' return
-        raw bytes, else decode according to self.encoding
+        :param length: maximum number of bytes to read
+        :return: value read from device
+        :rtype: bytes if self.mode is 'b', else decode with self.encoding
         """
         if not self._opened:
             raise FtdiError("read() on closed Device")
 
         # read the data
-        if self.buffer_size != 0:
+        if self.chunk_size != 0:
             remaining = length
             byte_data_list = []
             while remaining > 0:
-                rx_bytes = self._read(min(remaining, self.buffer_size))
+                rx_bytes = self._read(min(remaining, self.chunk_size))
                 if not rx_bytes:
                     break
                 byte_data_list.append(rx_bytes)
@@ -320,6 +333,9 @@ class Device(object):
     def _write(self, byte_data):
         """
         actually do the low level writing
+        :param byte_data: data to be written
+        :type byte_data: bytes
+        :return: number of bytes written
         """
         buf = create_string_buffer(byte_data)
         written = self.fdll.ftdi_write_data(byref(self.ctx),
@@ -331,10 +347,13 @@ class Device(object):
         write(data) -> count of bytes actually written
 
         write given `data` string to the FTDI device
-        returns count of bytes written, which may be less than `len(data)`
+
+        :param data: string to be written
+        :type data: string or bytes
+        :return: count of bytes written, which may be less than `len(data)`
         """
         if not self._opened:
-            raise FtdiError("read() on closed Device")
+            raise FtdiError("write() on closed Device")
 
         try:
             byte_data = bytes(data)
@@ -343,12 +362,12 @@ class Device(object):
             byte_data = data.encode(self.encoding)
 
         # actually write it
-        if self.buffer_size != 0:
+        if self.chunk_size != 0:
             remaining = len(byte_data)
             written = 0
             while remaining > 0:
                 start = written
-                length = min(remaining, self.buffer_size)
+                length = min(remaining, self.chunk_size)
                 result = self._write(byte_data[start: start + length])
                 if result == -1:
                     written == result
@@ -404,7 +423,9 @@ class Device(object):
         self.flush(FLUSH_OUTPUT)
 
     def get_error_string(self):
-        "return error string from libftdi driver"
+        """
+        :return: error string from libftdi driver
+        """
         return self.fdll.ftdi_get_error_string(byref(self.ctx))
 
     @property
@@ -433,6 +454,7 @@ class Device(object):
     def __enter__(self):
         """
         support for context manager.
+
         Note the device is opened and closed automatically
         when used in a with statement, and the device object
         itself is returned:
@@ -463,6 +485,9 @@ class Device(object):
         """
         readline() for file-like compatibility.
 
+        :param size: maximum amount of data to read looking for a line
+        :return: a line of text, or size bytes if no line-ending found
+
         This only works for mode='t' on Python3
         """
         lsl = len(os.linesep)
