@@ -1,11 +1,14 @@
 """
 Flash an LED connected via a FTDI UM232R/245R module using pylibftdi
 
+Optionally supply a flash rate (in Hz, default 1) as an argument
+
 Copyright (c) 2010-2012 Ben Bass <benbass@codedstructure.net>
 All rights reserved.
 """
 
 import time
+import sys
 from pylibftdi import BitBangDevice
 
 
@@ -18,5 +21,14 @@ def flash_forever(rate):
             time.sleep(1.0 / (2 * rate))
             bb.port ^= 1
 
+
+def main():
+    if len(sys.argv) > 1:
+        rate = float(sys.argv[1])
+        flash_forever(rate)
+    else:
+        flash_forever(1)
+
+
 if __name__ == '__main__':
-    flash_forever(1)
+    main()
